from setuptools import setup, find_packages

setup(
    name='rkkr',
    version='1.2',
    packages=find_packages(),
    install_requires=[
        'keras',
        'keras-tuner',
        'pandas',
        'numpy',
        'scikit-learn'
    ],
    entry_point={
        "console_scripts":[
            "rkkr = rkkr:welcome",
        ],
    },

)